package com.yiqi.core.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.GoodsCategory;

/**
 * 商品类型管理Mapper接口
 *
 * @author ruoyi
 * @date 2023-08-21
 */
public interface GoodsCategoryMapper extends BaseMapper<GoodsCategory> {
    /**
     * 查询商品类型管理
     *
     * @param id 商品类型管理主键
     * @return 商品类型管理
     */
    public GoodsCategory selectGoodsCategoryById(Long id);

    /**
     * 查询商品类型管理列表
     *
     * @param goodsCategory 商品类型管理
     * @return 商品类型管理集合
     */
    public List<GoodsCategory> selectGoodsCategoryList(GoodsCategory goodsCategory);

    /**
     * 新增商品类型管理
     *
     * @param goodsCategory 商品类型管理
     * @return 结果
     */
    public int insertGoodsCategory(GoodsCategory goodsCategory);

    /**
     * 修改商品类型管理
     *
     * @param goodsCategory 商品类型管理
     * @return 结果
     */
    public int updateGoodsCategory(GoodsCategory goodsCategory);

    /**
     * 删除商品类型管理
     *
     * @param id 商品类型管理主键
     * @return 结果
     */
    public int deleteGoodsCategoryById(Long id);

    /**
     * 批量删除商品类型管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGoodsCategoryByIds(Long[] ids);
}
